<h1>Chat<img src='https://github.com/yngtodd/chat/blob/master/img/snek.png' align='right' width='180' height='104'></h1>


[![Build Status](https://travis-ci.com/yngtodd/chat.svg?branch=master)](https://travis-ci.com/yngtodd/chat)
[![pypi](https://img.shields.io/pypi/v/le_chat.svg)](https://pypi.python.org/pypi/le_chat)


Data parallelism study for natural language processing.


* Free software: BSD license
* Documentation: https://chat.readthedocs.io.


#### Features

Chat comes with a built in command line interface:

```python
python -m chat.cli greet
```
